| backlink_Input | R Documentation |
This function adds a back link to the page
backlink_Input(inputId, label = "Back")
inputId |
The input slot that will be used to access the value |
label |
The link text for the backlink, default is "Back" |
a backlink HTML shiny tag object
Other Govstyle navigation:
contents_link(),
service_navigation(),
update_service_navigation()
ui <- shiny::fluidPage(
header(
org_name = "Example",
service_name = "User Examples",
logo = "shinyGovstyle/images/moj_logo.png"
),
shiny::navlistPanel(
"",
id = "nav",
widths = c(2, 10),
well = FALSE,
# Create first panel
shiny::tabPanel(
"Select Types",
value = "panel1",
gov_layout(
size = "two-thirds",
backlink_Input("link1"),
shiny::tags$br(),
shiny::tags$br()
)
),
shiny::tabPanel(
"Tab2",
value = "panel2"
)
),
shinyGovstyle::footer(full = TRUE)
)
server <- function(input, output, session) {
# Slightly confused in that it goes forward rather than back
# but shows how to use
observeEvent(input$link1, {
updateTabsetPanel(session, "nav", selected = "panel2")
})
}
if (interactive()) shinyApp(ui = ui, server = server)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.