bad_link_text: Lookup for bad link text

bad_link_textR Documentation

Description

A single column data frame, listing out known examples of bad link text that check for in the external_link() function.

Usage

bad_link_text

Format

bad_link_text

A data frame with 53 rows and 1 columns:

bad_link_text

Lower cased examples of non-descriptive link text

Details

We've started curating this list so we can create automated checks to help all link text to be as descriptive as possible in line with WCAG 2.2 success criteria 2.4.4: Link Purpose (In Context).

Curated by explore.statistics@education.gov.uk


shinyGovstyle documentation built on April 13, 2026, 5:06 p.m.