clean_heading_text: Clean heading text function This internal function is used in...

View source: R/clean_heading_text.R

clean_heading_textR Documentation

Clean heading text function This internal function is used in heading_text() to create an automated link between the two

Description

Clean heading text function This internal function is used in heading_text() to create an automated link between the two

Usage

clean_heading_text(text)

Arguments

text

string

Value

a string


shinyGovstyle documentation built on April 13, 2026, 5:06 p.m.