This function create a detail component that you can click for further details.
Arguments
- inputId
The id assigned to the component's root element. For Shiny input components this is also the name used to access the value via
input$<inputId>.- label
Main label text
- help_text
Additional help information in the component. Accepts a plain character string, or
shinytag objects such asshiny::tags$b("Bold")or ashiny::tagList().
See also
Other Govstyle feedback types:
gov_summary(),
insert_text(),
label_hint(),
noti_banner(),
panel_output(),
tag_Input(),
value_box(),
warning_text()
Examples
ui <- shinyGovstyle::gov_page(
shinyGovstyle::header(
org_name = "Example",
service_name = "User Examples",
logo = "shinyGovstyle/images/moj_logo.png"
),
shinyGovstyle::gov_layout(
size = "two-thirds",
shinyGovstyle::details(
inputId = "help_div",
label = "Help with form",
help_text = "To complete the form you need to fill it in..."
)
),
shinyGovstyle::footer(full = TRUE)
)
server <- function(input, output, session) {}
if (interactive()) shinyApp(ui = ui, server = server)