Loads the GDS Transport font for use in your app. GDS Transport is a restricted typeface that must only be used on GOV.UK domains. If your app is not hosted on a GOV.UK domain, do not call this function — the GOV.UK Frontend CSS will fall back to Helvetica or Arial automatically.
Details
See the GOV.UK typeface guidance for full details on when GDS Transport is permitted.
Examples
ui <- shinyGovstyle::gov_page(
font(),
shinyGovstyle::header(
org_name = "Example",
service_name = "User Examples",
logo="shinyGovstyle/images/moj_logo.png")
)
server <- function(input, output, session) {}
if (interactive()) shinyApp(ui = ui, server = server)