View source: R/full_width_overrides.R
| full_width_overrides | R Documentation |
This is an experimental function that will likely be removed in future
releases, as we work through updating the core package styling and
adding full width options into the components themselves. This is not
well tested and may cause unexpected styling issues when combined with
components from other packages, use at your own risk.
full_width_overrides()
HTML containing CSS styling overrides
Other Govstyle styling:
font()
shinyGovstyle::full_width_overrides()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.