| govTabs | R Documentation |
This function creates a tabs based table. It requires a single dataframe with a grouping variable.
govTabs(inputId, df, group_col)
inputId |
The Id to access the tag |
df |
A single dataframe with all data. See example for structure |
group_col |
The column name with the groups to be used as tabs |
a tab table HTML shiny tag object
Other Govstyle tables tabs and accordions:
accordion(),
govReactable(),
govReactable-shiny,
govTable()
ui <- shiny::fluidPage(
shinyGovstyle::header(
org_name = "Example",
service_name = "User Examples",
logo = "shinyGovstyle/images/moj_logo.png",
logo_alt_text = "Ministry of Justice logo"
),
shinyGovstyle::gov_main_layout(
size = "two-thirds",
shinyGovstyle::govTabs("tabs", shinyGovstyle::case_data, "tabs")
),
shinyGovstyle::footer(full = TRUE)
)
server <- function(input, output, session) {}
if (interactive()) shinyApp(ui = ui, server = server)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.