panel_output: Panel output

View source: R/panel_output.R

panel_outputR Documentation

Panel output

Description

This function inserts a panel. Normally used for confirmation screens

Usage

panel_output(inputId, main_text, sub_text)

Arguments

inputId

The input slot that will be used to access the value.

main_text

Add the header for the panel

sub_text

Add the main body of text for the panel

Value

a panel HTML shiny tag object

See Also

Other Govstyle feedback types: details(), gov_summary(), insert_text(), label_hint(), noti_banner(), tag_Input(), value_box(), warning_text()

Examples

ui <- shiny::fluidPage(
  shinyGovstyle::header(
    org_name = "Example",
    service_name = "User Examples",
    logo="shinyGovstyle/images/moj_logo.png"
  ),
  shinyGovstyle::gov_layout(size = "full",
    shinyGovstyle::panel_output(
      inputId = "panel1",
      main_text = "Application Complete",
      sub_text = paste(
        "Thank you for submitting your application.",
        "Your reference is xvsiq"
      )
    ),
    shinyGovstyle::footer(full = TRUE)
  )
)

server <- function(input, output, session) {}
if (interactive()) shinyApp(ui = ui, server = server)

shinyGovstyle documentation built on April 13, 2026, 5:06 p.m.