run_example: Run examples

View source: R/run_example.R

run_exampleR Documentation

Run examples

Description

This function runs an example R Shiny app showcasing different parts of the package. Code for the app can be found in the inst/example_app folder in the source code.

Usage

run_example()

Details

The app uses the bslib package as is generally recommended for Shiny apps.

The app is also deployed at the following URL: https://department-for-education.shinyapps.io/shinygovstyle-example-app/

Value

runs an R Shiny app with examples in

Examples

if (interactive()) run_example()

shinyGovstyle documentation built on April 13, 2026, 5:06 p.m.