| select_Input | R Documentation |
This function inserts a select box
select_Input(inputId, label, select_text, select_value)
inputId |
Input Id for the component |
label |
Insert the text for the label |
select_text |
Add the text that will apply in the drop down as a list |
select_value |
Add the value that will be used for each selection |
a select input HTML shiny tag object
Other Govstyle select inputs:
button_Input(),
checkbox_Input(),
file_Input(),
radio_button_Input()
ui <- shiny::fluidPage(
shinyGovstyle::header(
org_name = "Example",
service_name = "User Examples",
logo = "shinyGovstyle/images/moj_logo.png",
logo_alt_text = "Ministry of Justice logo"
),
shinyGovstyle::gov_layout(
size = "full",
select_Input(
inputId = "sorter",
label = "Sort by",
select_text = c(
"Recently published",
"Recently updated",
"Most views",
"Most comments"
),
select_value = c("published", "updated", "view", "comments")
),
shiny::tags$br()
),
shinyGovstyle::footer(full = TRUE)
)
server <- function(input, output, session) {}
if (interactive()) shinyApp(ui = ui, server = server)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.