skip_to_main: Skip to main content link

View source: R/skip_to_main.R

skip_to_mainR Documentation

Skip to main content link

Description

This function generates a 'Skip to main content' link, which is typically used by keyboard users to bypass content and navigate directly to the main content of a page.

Usage

skip_to_main(id = "main")

Arguments

id

An optional parameter to specify the Id of the main content section, will be automatically preceeded by a hash '#'. Default is "main" to match the "#main" Id within gov_main().

Value

A Shiny tag representing the 'Skip to main content' link

See Also

Other Govstyle page structure: banner(), cookieBanner(), footer(), gov_layout(), header(), layouts

Examples

ui <- shiny::fluidPage(
  skip_to_main(),
  header(
    org_name = "Example",
    service_name = "User Examples",
    logo="shinyGovstyle/images/moj_logo.png"
  ),
  gov_main_layout(
    heading_text("Example heading"),
  )
)

server <- function(input, output, session){}

if (interactive()) shinyApp(ui = ui, server = server)

shinyGovstyle documentation built on April 13, 2026, 5:06 p.m.