Skip to contents

This function inserts a accordion

Usage

accordion(inputId, titles, descriptions)

Arguments

inputId

Input Id for the accordion

titles

Add the titles for the accordion

descriptions

Add the main text for the accordion

Value

an accordion HTML shiny tag object

See also

Other Govstyle tables tabs and accordions: govReactable(), govReactable-shiny, govTable(), govTabs()

Examples

ui <- shiny::fluidPage(
  shinyGovstyle::header(
    org_name = "Example",
    service_name = "User Examples",
    logo = "shinyGovstyle/images/moj_logo.png",
    logo_alt_text = "Ministry of Justice logo"
  ),
  shinyGovstyle::banner(
    inputId = "banner", type = "beta", 'This is a new service'
  ),
  shinyGovstyle::gov_layout(
    size = "two-thirds",
    accordion(
      "acc1",
      c(
        "Writing well for the web",
        "Writing well for specialists",
        "Know your audience",
        "How people read"
      ),
      c(
        "This is the content for Writing well for the web.",
        "This is the content for Writing well for specialists.",
        "This is the content for Know your audience.",
        "This is the content for How people read."
      )
    )
  ),
  shinyGovstyle::footer(full = TRUE)
)
#> Warning: The `main_link` argument of `header()` is deprecated as of shinyGovstyle 0.2.0.
#>  main_link will be dropped in v1.0.0
#> Warning: The `main_alt_text` argument of `header()` is deprecated as of shinyGovstyle
#> 0.2.0.
#>  main_alt_text will be dropped in v1.0.0
#> Warning: The `secondary_alt_text` argument of `header()` is deprecated as of
#> shinyGovstyle 0.2.0.
#>  secondary_alt_text will be dropped in v1.0.0
#> Warning: The `secondary_link` argument of `header()` is deprecated as of shinyGovstyle
#> 0.2.0.
#>  secondary_link will be dropped in v1.0.0

server <- function(input, output, session) {}

if (interactive()) shiny::shinyApp(ui = ui, server = server)