| bad_link_text | R Documentation |
A single column data frame, listing out known examples of bad link text that
check for in the external_link() function.
bad_link_text
bad_link_textA data frame with 53 rows and 1 columns:
Lower cased examples of non-descriptive link text
We've started curating this list so we can create automated checks to help all link text to be as descriptive as possible in line with WCAG 2.2 success criteria 2.4.4: Link Purpose (In Context).
Curated by explore.statistics@education.gov.uk
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.