banner: Banner Function

View source: R/banner.R

bannerR Documentation

Description

This function create a detail component that you can click for further details.

Usage

banner(inputId, type, label)

Arguments

The input slot that will be used to access the value

Main type of label e.g. alpha or beta. Can be any word

text to display

Value

a banner HTML shiny tag object

See Also

Other Govstyle page structure: cookieBanner(), footer(), gov_layout(), header(), layouts, skip_to_main()

Examples

ui <- shiny::fluidPage(
  shinyGovstyle::header(
    org_name = "Example",
    service_name = "User Examples",
    logo = "shinyGovstyle/images/moj_logo.png"
  ),
  shinyGovstyle::banner(
    inputId = "banner", type = "Beta", 'This is a new service'
  )
)

server <- function(input, output, session) {}

if (interactive()) shinyApp(ui = ui, server = server)

shinyGovstyle documentation built on April 13, 2026, 5:06 p.m.