| banner | R Documentation |
This function create a detail component that you can click for further details.
banner(inputId, type, label)
inputId |
The input slot that will be used to access the value |
type |
Main type of label e.g. alpha or beta. Can be any word |
label |
text to display |
a banner HTML shiny tag object
Other Govstyle page structure:
cookieBanner(),
footer(),
gov_layout(),
header(),
layouts,
skip_to_main()
ui <- shiny::fluidPage(
shinyGovstyle::header(
org_name = "Example",
service_name = "User Examples",
logo = "shinyGovstyle/images/moj_logo.png"
),
shinyGovstyle::banner(
inputId = "banner", type = "Beta", 'This is a new service'
)
)
server <- function(input, output, session) {}
if (interactive()) shinyApp(ui = ui, server = server)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.