This function create a header banner. For use at top of the screen
Usage
header(
org_name = "Shiny example app",
service_name = NULL,
logo = "shinyGovstyle/images/Dept_logo.svg",
main_text = lifecycle::deprecated(),
secondary_text = lifecycle::deprecated(),
main_link = lifecycle::deprecated(),
secondary_link = lifecycle::deprecated(),
logo_alt_text = "Departmental logo",
main_alt_text = lifecycle::deprecated(),
secondary_alt_text = lifecycle::deprecated(),
logo_width = 66,
logo_height = 34,
width = "standard"
)Arguments
- org_name
Organisation name that goes in the header
- service_name
Service name to supplement the organisation name
- logo
Add a link to a logo which will apply in the header. Use crown to use the crown SVG version on GOV UK
- main_text
- secondary_text
- main_link
- secondary_link
- logo_alt_text
Add alternative text for the logo. Should be used when a logo is used
- main_alt_text
Add alternative text for the main link. Should be used when a main link is used
- secondary_alt_text
Add alternative text for the secondary link. Should be used when a secondary link is used
- logo_width
Change the logo size width CSS to improve fit
- logo_height
Change the logo size height CSS to improve fit
- width
Width of the component. One of
"standard"(the default, GOV.UK's usual 960px content width),"three-quarters"(three-quarters of the viewport, never narrower than standard),"full"(no max-width, so the container fills the viewport, with grid gutters also removed), or a CSS length (e.g."1400px","90vw") for a custom max-width.
See also
Other Govstyle page structure:
banner(),
cookieBanner(),
footer(),
gov_layout(),
gov_page(),
layouts,
skip_to_main()
Examples
ui <- shinyGovstyle::gov_page(
shinyGovstyle::header(
org_name = "Example",
service_name = "User Examples",
logo = "shinyGovstyle/images/moj_logo.png",
logo_alt_text = "Ministry of Justice Logo"
)
)
server <- function(input, output, session) {}
if (interactive()) shinyApp(ui = ui, server = server)