This function loads the insert text component to display additional information in a special format.
Usage
insert_text(inputId, content, text = lifecycle::deprecated())Arguments
- inputId
The input slot that will be used to access the value
- content
Content to display on the insert. Accepts a plain character string, or
shinytag objects such asshiny::tags$b("Bold")or ashiny::tagList().- text
See also
Other Govstyle feedback types:
details(),
gov_summary(),
label_hint(),
noti_banner(),
panel_output(),
tag_Input(),
value_box(),
warning_text()
Examples
ui <- shiny::fluidPage(
shinyGovstyle::header(
org_name = "Example",
service_name = "User Examples",
logo="shinyGovstyle/images/moj_logo.png"
),
shinyGovstyle::gov_layout(
size = "two-thirds",
shinyGovstyle::insert_text(
inputId = "note",
content = paste(
"It can take up to 8 weeks to register a lasting power of",
"attorney if there are no mistakes in the application."
)
),
shinyGovstyle::insert_text(
inputId = "note-rich",
content = shiny::tagList(
shiny::tags$b("Important: "),
"you can also pass tag objects."
)
)
),
shinyGovstyle::footer(full = TRUE)
)
server <- function(input, output, session) {}
if (interactive()) shinyApp(ui = ui, server = server)