| insert_text | R Documentation |
This function loads the insert text component to display additional information in a special format.
insert_text(inputId, text)
inputId |
The input slot that will be used to access the value |
text |
Text that you want to display on the insert |
a insert text HTML shiny tag object
Other Govstyle feedback types:
details(),
gov_summary(),
label_hint(),
noti_banner(),
panel_output(),
tag_Input(),
value_box(),
warning_text()
ui <- shiny::fluidPage(
shinyGovstyle::header(
org_name = "Example",
service_name = "User Examples",
logo="shinyGovstyle/images/moj_logo.png"
),
shinyGovstyle::gov_layout(
size = "two-thirds",
shinyGovstyle::insert_text(
inputId = "note",
text = paste(
"It can take up to 8 weeks to register a lasting power of",
"attorney if there are no mistakes in the application."
)
)
),
shinyGovstyle::footer(full = TRUE)
)
server <- function(input, output, session) {}
if (interactive()) shinyApp(ui = ui, server = server)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.