| panel_output | R Documentation |
This function inserts a panel. Normally used for confirmation screens
panel_output(inputId, main_text, sub_text)
inputId |
The input slot that will be used to access the value. |
main_text |
Add the header for the panel |
sub_text |
Add the main body of text for the panel |
a panel HTML shiny tag object
Other Govstyle feedback types:
details(),
gov_summary(),
insert_text(),
label_hint(),
noti_banner(),
tag_Input(),
value_box(),
warning_text()
ui <- shiny::fluidPage(
shinyGovstyle::header(
org_name = "Example",
service_name = "User Examples",
logo="shinyGovstyle/images/moj_logo.png"
),
shinyGovstyle::gov_layout(size = "full",
shinyGovstyle::panel_output(
inputId = "panel1",
main_text = "Application Complete",
sub_text = paste(
"Thank you for submitting your application.",
"Your reference is xvsiq"
)
),
shinyGovstyle::footer(full = TRUE)
)
)
server <- function(input, output, session) {}
if (interactive()) shinyApp(ui = ui, server = server)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.