| radio_button_Input | R Documentation |
This function create radio buttons
radio_button_Input(
inputId,
label,
choices = NULL,
selected = NULL,
inline = FALSE,
small = FALSE,
choiceNames = NULL,
choiceValues = NULL,
hint_label = NULL,
error = FALSE,
error_message = NULL,
custom_class = ""
)
inputId |
The |
label |
Input label |
choices |
List of values to select from (if elements of the list are named then that name rather than the value is displayed to the user) |
selected |
The initially selected value. |
inline |
If you want the radio inline or not, Default is FALSE |
small |
If you want the smaller versions of radio buttons, Default is FALSE |
choiceNames, choiceValues |
Same as in
|
hint_label |
Additional hint text you may want to display below the label. Defaults to NULL |
error |
Whenever you want to include error handle on the component |
error_message |
If you want a default error message |
custom_class |
If you want to add additional classes to the radio buttons |
radio buttons HTML shiny tag object
Other Govstyle select inputs:
button_Input(),
checkbox_Input(),
file_Input(),
select_Input()
ui <- shiny::fluidPage(
# Required for error handling function
shinyjs::useShinyjs(),
shinyGovstyle::header(
org_name = "Example",
service_name = "User Examples",
logo = "shinyGovstyle/images/moj_logo.png"
),
shinyGovstyle::banner(
inputId = "banner", type = "beta", "This is a new service"
),
shinyGovstyle::gov_layout(
size = "two-thirds",
# Simple radio
shinyGovstyle::radio_button_Input(
inputId = "radio1",
choices = c("Yes", "No", "Maybe"),
label = "Choice option"
),
# Error radio
shinyGovstyle::radio_button_Input(
inputId = "radio2",
choices = c("Yes", "No", "Maybe"),
label = "Choice option",
hint_label = "Select the best fit",
inline = TRUE,
error = TRUE,
error_message = "Select one"
),
# Button to trigger error
shinyGovstyle::button_Input(inputId = "submit", label = "Submit")
),
shinyGovstyle::footer(full = TRUE)
)
server <- function(input, output, session) {
# Trigger error on blank submit of eventId2
observeEvent(input$submit, {
if (is.null(input$radio2)) {
shinyGovstyle::error_on(inputId = "radio2")
} else {
shinyGovstyle::error_off(
inputId = "radio2"
)
}
})
}
if (interactive()) shinyApp(ui = ui, server = server)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.