| run_example | R Documentation |
This function runs an example R Shiny app showcasing different parts of the package. Code for the app can be found in the inst/example_app folder in the source code.
run_example()
The app uses the bslib package as is generally recommended for Shiny apps.
The app is also deployed at the following URL: https://department-for-education.shinyapps.io/shinygovstyle-example-app/
runs an R Shiny app with examples in
if (interactive()) run_example()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.