| skip_to_main | R Documentation |
This function generates a 'Skip to main content' link, which is typically used by keyboard users to bypass content and navigate directly to the main content of a page.
skip_to_main(id = "main")
id |
An optional parameter to specify the Id of the main content
section, will be automatically preceeded by a hash '#'. Default is
"main" to match the "#main" Id within |
A Shiny tag representing the 'Skip to main content' link
Other Govstyle page structure:
banner(),
cookieBanner(),
footer(),
gov_layout(),
header(),
layouts
ui <- shiny::fluidPage(
skip_to_main(),
header(
org_name = "Example",
service_name = "User Examples",
logo="shinyGovstyle/images/moj_logo.png"
),
gov_main_layout(
heading_text("Example heading"),
)
)
server <- function(input, output, session){}
if (interactive()) shinyApp(ui = ui, server = server)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.