text_area_Input: Text Area Input Function

text_area_InputR Documentation

Text Area Input Function

Description

This function create a text area input.

Usage

text_area_Input(
  inputId,
  label,
  hint_label = NULL,
  row_no = 5,
  error = FALSE,
  error_message = NULL,
  word_limit = NULL
)

Arguments

inputId

The input slot that will be used to access the value

label

Display label for the control, or NULL for no label

hint_label

Display hint label for the control, or NULL for no hint label

row_no

Size of the text entry box. Defaults to 5

error

Whenever to include error handling. Defaults to FALSE

error_message

Message to display on error. Defaults to NULL

word_limit

Add a word limit to the display. Defaults to NULL

Value

a text area box HTML shiny tag object

See Also

Other Govstyle text types: date_Input(), gov_list(), heading_text(), input_field(), text_Input(), word_count()

Examples

text_area_Input(
  "taId",
  "Can you provide more detail?",
  paste(
    "Do not include personal or financial information, like your",
    "National Insurance number or credit card details."
  )
)

shinyGovstyle documentation built on April 13, 2026, 5:06 p.m.