| text_area_Input | R Documentation |
This function create a text area input.
text_area_Input(
inputId,
label,
hint_label = NULL,
row_no = 5,
error = FALSE,
error_message = NULL,
word_limit = NULL
)
inputId |
The input slot that will be used to access the value |
label |
Display label for the control, or |
hint_label |
Display hint label for the control, or |
row_no |
Size of the text entry box. Defaults to 5 |
error |
Whenever to include error handling. Defaults to |
error_message |
Message to display on error. Defaults to |
word_limit |
Add a word limit to the display. Defaults to |
a text area box HTML shiny tag object
Other Govstyle text types:
date_Input(),
gov_list(),
heading_text(),
input_field(),
text_Input(),
word_count()
text_area_Input(
"taId",
"Can you provide more detail?",
paste(
"Do not include personal or financial information, like your",
"National Insurance number or credit card details."
)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.