| word_count | R Documentation |
This function create tracks the word count and should be used with the text area function.
word_count(inputId, input, word_limit = NULL)
inputId |
The input slot of the text area that you want to affect |
input |
The text input that is associated with the box |
word_limit |
Change the word limit if needed. Default will keep as what was used in text area component |
no value returned. Updates the word count in a shiny app
Other Govstyle text types:
date_Input(),
gov_list(),
heading_text(),
input_field(),
text_Input(),
text_area_Input()
ui <- shiny::fluidPage(
shinyjs::useShinyjs(),
shinyGovstyle::header(
"Justice", "", logo = "shinyGovstyle/images/moj_logo.png"
),
gov_layout(
size = "full",
text_area_Input(
inputId = "text_area",
label = "Can you provide more detail?",
hint_label = paste(
"Do not include personal or financial information,",
"like your National Insurance number or credit card details."
),
word_limit = 300
)
),
footer(TRUE)
)
server <- function(input, output, session) {
shiny::observeEvent(input$text_area,
word_count(
inputId = "text_area",
input = input$text_area
)
)
}
if (interactive()) shinyApp(ui = ui, server = server)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.